@@ -1,2 +1,2 @@
 """ Numba @njittable MPI wrappers tested on Linux, macOS and Windows """
-from .mpi import initialized, size, rank, send, recv
+from .mpi import initialized, size, rank, send, recv, allreduce
